# How to Python in computational neuroscience, data mining, and more 
{:.no_toc}

<nav markdown="1" class="toc-class">
* TOC
{:toc}
</nav>

All the tutorials are tested with Python 3.11.x. Older version might have a problem with the new versions of type anotations. 

## Flow chart
* [Flow chart symbols](flow/overview/README.md)
* [Examples](flow/examples/README.md)
* [Flow chart for baking bread](flow/baking_bread/README.md)

## Workflow
* [Python installation](workflow/python_pure/README.md)
* [VS Code installation](workflow/vscode_install/README.md)
* [VS Code configuration](workflow/vscode_config/README.md)
* [VS Code Markdown](workflow/vscode_markdown/README.md)


## Python: The Basics of the basics
* [Overview](python_basics/where_to_start/README.md)
* [Hello, Python](python_basics/hello_python/README.md)
* [Style Rulez](python_basics/style_rulez/README.md)
* [Programming Recommendations](python_basics/programming_recommendations/README.md)
* [Basic Math Operations](python_basics/basic_math_operations/README.md)
* [Truth Value Testing](python_basics/truth_value_testing/README.md)
* [Formatted String Literals](python_basics/formatted_string_literals/README.md)
* [Flow Control Overview](python_basics/flow_control_overview/README.md)
  - [Flow Control: if, elif, else](python_basics/if/README.md)
  - [Flow Control: for-loop](python_basics/for/README.md)
  - [Flow Control: while, pass, break, continue](python_basics/while/README.md)
  - [Flow Control: match case](python_basics/match/README.md)
* Sequence Types
  - [Lists](python_basics/list/README.md)
  - [Tuple](python_basics/tuple/README.md)
* Mapping Types
  - [Dict​](python_basics/dict/README.md)
* [Files](python_basics/files/README.md)
* [JSON and dict for parameter files](python_basics/json/README.md)
* [Creating order via sub-directories: os.makedirs](python_basics/os_makedirs/README.md)
* [Finding files in a directory: glob](python_basics/glob/README.md)
* [Class](python_basics/class/README.md)
* [Exceptions (try / except)](python_basics/exceptions/README.md)
* [The Python Standard Library​](python_basics/standard_libraries/README.md)


## Numpy
* [Beyond normal np.save](numpy_save_special/README.md)
* [Dealing with Matlab files](numpy_mat_files/README.md)

## Python: Data analysis

* [Numpy: Random numbers the non-legacy way](numpy_random/README.md)
* [Remove a common signal from your data](SVD_data_cleaning/README.md)

## Python: Questions of spectral nature

* [Numpy: rfft and spectral power](numpy_fft_1/README.md)
* [scipy.signal: Butterworth low, high and band-pass](scipy.signal_butterworth/README.md)
* [PyWavelets: Wavelet Transforms in Python](pywavelet/README.md)


## Python: Daily little helper

* [TQDM: Make your progress visible](helper/TQDM/README.md)
* [Argh: Organize your command line arguments](helper/argh/README.md)


## PyTorch 
* [Get CUDA ready!](pytorch/cuda/README.md)
* [Layers](pytorch/layers/README.md)

## Matlab: Basics
* [Basic Structure of a Computer](matlab/1/README.md)
* [Representation of Numbers in the Computer](matlab/2/README.md)

Note: I will transfer the old pages to this new place (and update it). It will take some time but it will happen... 
